"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MarkdownStreamer = void 0;
const MarkdownParser_1 = require("./MarkdownParser");
class MarkdownStreamer {
    constructor() {
        this.parser = new MarkdownParser_1.MarkdownParser();
    }
    get transformStream() {
        return new TransformStream({
            transform: (chunk, controller) => {
                const html = this.parser.parseChunk(typeof chunk === "string" ? chunk : new TextDecoder().decode(chunk));
                if (html)
                    controller.enqueue(html);
            },
            flush: (controller) => {
                const finalHtml = this.parser.finalize();
                if (finalHtml)
                    controller.enqueue(finalHtml);
            },
        });
    }
    // Alternative node.js stream interface
    nodeStream() {
        return new (require("stream").Transform)({
            transform: (chunk, encoding, callback) => {
                try {
                    // console.log("nodeStream chunk", chunk.toString());
                    const html = this.parser.parseChunk(chunk.toString());
                    callback(null, html);
                }
                catch (err) {
                    callback(err);
                }
            },
            flush: (callback) => {
                try {
                    const finalHtml = this.parser.finalize();
                    callback(null, finalHtml);
                }
                catch (err) {
                    callback(err);
                }
            },
        });
    }
}
exports.MarkdownStreamer = MarkdownStreamer;
