"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.syntaxHighlightPlugin = syntaxHighlightPlugin;
exports.tablePlugin = tablePlugin;
exports.inlineStylesPlugin = inlineStylesPlugin;
exports.imagePlugin = imagePlugin;
exports.linkPlugin = linkPlugin;
const highlight_js_1 = __importDefault(require("highlight.js"));
const utills_1 = require("./utills");
function syntaxHighlightPlugin(token) {
    console.log(token);
    if (token.content) {
        const language = token.language || "plaintext"; // Default to plaintext if no language is specified
        // Check if the language is supported by highlight.js
        if (highlight_js_1.default.getLanguage(language)) {
            // Highlight the code using highlight.js
            const highlightedCode = highlight_js_1.default.highlight(token.content, { language }).value;
            // Return the highlighted code as HTML
            return `<pre class="hljs"><code class="language-${language}">${highlightedCode}</code></pre>`;
        }
        else {
            // Fallback for unsupported languages or plaintext
            return `<pre class="hljs"><code>${(0, utills_1.escapeHtml)(token.content)}</code></pre>`;
        }
    }
    return null; // Return null if there's no content
}
/**
 * Table plugin to convert table tokens to HTML
 */
function tablePlugin(token) {
    if (token.type === "table" && token.content) {
        const rows = token.content
            .trim()
            .split("\n")
            .map((row) => row.trim())
            .filter((row) => row.length > 0);
        if (rows.length < 2) {
            return null;
        }
        const headers = rows[0]
            .split("|")
            .map((header) => header.trim())
            .filter((header) => header !== "")
            .map((header) => `<th>${header}</th>`)
            .join("");
        const body = rows
            .slice(2)
            .map((row) => `<tr>${row
            .split("|")
            .map((cell) => cell.trim())
            .filter((cell) => cell !== "")
            .map((cell) => `<td>${cell}</td>`)
            .join("")}</tr>`)
            .join("");
        return `<table><thead><tr>${headers}</tr></thead><tbody>${body}</tbody></table>`;
    }
    return null;
}
function inlineStylesPlugin(token) {
    if (token.type === "paragraph" &&
        token.content &&
        (/<.*?>/.test(token.content) ||
            /\*\*.*?\*\*|__.*?__|\*.*?\*|_.*?_|~~.*?~~|`.*?`/.test(token.content))) {
        let content = token.content;
        content = (0, utills_1.escapeHtml)(content);
        content = content.replace(/(\*\*|__)(.*?)\1/g, "<strong>$2</strong>");
        content = content.replace(/(\*|_)(.*?)\1/g, "<em>$2</em>");
        content = content.replace(/~~(.*?)~~/g, "<del>$1</del>");
        content = content.replace(/`(.*?)`/g, "<code>$1</code>");
        return `<p>${content}</p>`;
    }
    return null;
}
function imagePlugin(token) {
    if (token.type === "paragraph" &&
        token.content &&
        /!\[([^\]]*)\]\(([^)]+)\)/.test(token.content)) {
        const res = token.content.replace(/!\[([^\]]*)\]\(([^)]+)\)/g, (_, altText, src) => `<img src="${src}" alt="${altText || ""}">`);
        return `<p>${res}</p>`;
    }
    return null;
}
function linkPlugin(token) {
    if (token.type === "paragraph" &&
        token.content &&
        /\[([^\]]+)\]\(([^)]+)\)/.test(token.content)) {
        const res = token.content.replace(/\[([^\]]+)\]\(([^)]+)\)/g, (_, text, href) => `<a href="${href}" target="_blank" rel="noopener noreferrer">${text}</a>`);
        return `<p>${res}</p>`;
    }
    return null;
}
