"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.processMarkdown = processMarkdown;
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const MarkdownParser_1 = require("./MarkdownParser"); // Update with your actual parser
const defaultOptions = {
    recursive: false,
    copyAssets: false,
    markdownExtensions: ['.md'],
};
function processMarkdown(inputDir, outputDir, options) {
    return __awaiter(this, void 0, void 0, function* () {
        const mergedOptions = Object.assign(Object.assign({}, defaultOptions), options);
        const logger = mergedOptions.logger || {
            info: console.log,
            error: (err, msg) => console.error(msg, err),
        };
        // Validate input directory
        if (!fs_1.default.existsSync(inputDir)) {
            throw new Error(`Input directory does not exist: ${inputDir}`);
        }
        // Create output directory structure
        yield fs_1.default.promises.mkdir(outputDir, { recursive: true });
        // Get all files respecting recursive option
        const files = yield getFiles(inputDir, mergedOptions.recursive);
        // Process files in parallel with error handling
        yield Promise.all(files.map((filePath) => __awaiter(this, void 0, void 0, function* () {
            var _a, _b, _c, _d;
            try {
                const relativePath = path_1.default.relative(inputDir, filePath);
                const outputPath = path_1.default.join(outputDir, relativePath);
                const outputDirPath = path_1.default.dirname(outputPath);
                // Create output directory structure for this file
                yield fs_1.default.promises.mkdir(outputDirPath, { recursive: true });
                // Check if file is Markdown
                const isMarkdown = (_a = mergedOptions.markdownExtensions) === null || _a === void 0 ? void 0 : _a.some(ext => filePath.toLowerCase().endsWith(ext.toLowerCase()));
                if (isMarkdown) {
                    // Process Markdown file
                    const markdownContent = yield fs_1.default.promises.readFile(filePath, 'utf-8');
                    const parser = new MarkdownParser_1.MarkdownParser();
                    const htmlContent = parser.render(markdownContent);
                    const finalHtml = mergedOptions.template
                        ? mergedOptions.template(htmlContent, filePath)
                        : htmlContent;
                    // Change extension to .html
                    const newPath = outputPath.replace(new RegExp(`${path_1.default.extname(filePath)}$`), '.html');
                    yield fs_1.default.promises.writeFile(newPath, finalHtml, 'utf-8');
                    (_b = logger.info) === null || _b === void 0 ? void 0 : _b.call(logger, `Converted: ${filePath} → ${newPath}`);
                }
                else if (mergedOptions.copyAssets) {
                    // Copy non-Markdown file
                    yield fs_1.default.promises.copyFile(filePath, outputPath);
                    (_c = logger.info) === null || _c === void 0 ? void 0 : _c.call(logger, `Copied: ${filePath} → ${outputPath}`);
                }
            }
            catch (err) {
                (_d = logger.error) === null || _d === void 0 ? void 0 : _d.call(logger, err, `Error processing ${filePath}`);
            }
        })));
    });
}
/** Recursively get all files in a directory */
function getFiles(dir_1) {
    return __awaiter(this, arguments, void 0, function* (dir, recursive = true) {
        try {
            const entries = yield fs_1.default.promises.readdir(dir, { withFileTypes: true });
            const files = yield Promise.all(entries.map((entry) => __awaiter(this, void 0, void 0, function* () {
                const fullPath = path_1.default.join(dir, entry.name);
                if (entry.isDirectory()) {
                    return recursive ? getFiles(fullPath, recursive) : [];
                }
                return [fullPath];
            })));
            return files.flat();
        }
        catch (error) {
            return [];
        }
    });
}
