import { Token } from "./tokenize";
/**
 * Markdown parser class
 */
export declare class MarkdownParser {
    private plugins;
    private useSyntaxHighlighting;
    private inCodeBlock;
    private buffer;
    private currentList;
    constructor();
    /**
     * Allows additional plugins to be registered
     * @param plugin A function that processes a token and returns HTML or null
     */
    use(plugin: (token: Token) => string | null): this;
    /**
     * Enables or disables syntax highlighting
     * @param enable A boolean indicating whether to enable syntax highlighting
     */
    enableSyntaxHighlighting(enable: boolean): this;
    /**
     * Renders Markdown input into HTML
     * @param input The Markdown string to be rendered
     * @returns Rendered HTML string
     */
    render(input: string): string;
    /**
     * Resets the parser to its initial state
     */
    reset(): void;
    /**
     * Parses a chunk of Markdown text
     * @param chunk A chunk of Markdown text
     * @returns The parsed HTML string
     */
    parseChunk(chunk: string): string;
    finalize(): string;
    private tokenizeStream;
    private _parseLine;
    private parseRegularLine;
    private parseInlineElements;
    private parseCodeBlockLine;
}
